.. include:: ../README.rst

----

.. include:: recipes.rst

----

.. include:: cheatsheet.rst

----

.. include:: creating_files.rst

----

.. include:: creating_images.rst

----

.. include:: creating_pdf.rst

----

.. include:: creating_docx.rst

----

.. include:: creating_odt.rst

----

.. include:: creating_archives.rst

----

.. include:: factories.rst

----

.. include:: customisation.rst

----

.. include:: cli.rst

----

.. include:: security.rst

----

.. include:: contributor_guidelines.rst

----

.. include:: changelog.rst

----

.. include:: package.rst
